@@ -1,4 +1,3 @@
-# 'makeArgs' internal generic to generate arguments from combination of
 # term names (a character vector), additional list of arbitrary options is accepted.
 # This is much a reverse action to getAllTerms
 makeArgs <- function(obj, termNames, opt, ...) UseMethod("makeArgs", obj)
@@ -33,7 +32,9 @@ function(obj, termNames, opt, ...) {
 	reportProblems <- character(0L)
 	termNames[termNames %in% opt$interceptLabel] <- "1"
 	## XXX: what if length(opt$intercept) > 1 ???
-	f <- reformulate(c(if(!opt$intercept) "0", termNames), response = opt$response)
+	f <- reformulate(c(if(!opt$intercept) "0" else if (!length(termNames)) "1", termNames), response = opt$response)
+	
+
 	environment(f) <- opt$gmFormulaEnv
 	ret <- list(formula = f)
 	if(!is.null(opt$gmCall$start)) {
@@ -79,61 +80,6 @@ function(obj, termNames, opt, ...) {
 }
 
 
-# used by makeArgs.unmarkedFit*
-`.makeUnmarkedFitFunnyFormulas` <- 
-function(termNames, opt, fnames) {
-	i <- termNames %in% opt$interceptLabel
-	termNames[i] <- gsub("(Int)", "(1)", termNames[i], fixed = TRUE)
-	zexpr <- lapply(termNames, function(x) parse(text = x)[[1L]])
-	zsplt <- split(sapply(zexpr, "[[", 2L), as.character(sapply(zexpr, "[[", 1L)))
-	zarg <- lapply(zsplt, function(x) reformulate(as.character(x)))
-	zarg <- zarg[fnames]
-	names(zarg) <- fnames
-	i <- sapply(zarg, is.null)
-	zarg[i] <- rep(list(~ 1), sum(i))
-	zarg <- lapply(zarg, `environment<-`, opt$gmFormulaEnv)
-	#print(zarg)
-	zarg
-}
-
-# This works for all the child classes provided that the arguments containing
-# formulas are named *formula, and they are at the beginnning of the call, and
-# if there is no more than 6 of them, and if there is a single 'formula'
-# argument it is doubly-one-sided.
-# Guessing the argument names is only negligibly slower than when they are
-# provided to the function, so the methods for child classes are commented out.
-
-`makeArgs.unmarkedFit` <- 
-function(obj, termNames, opt,
-	fNames = sapply(obj@estimates@estimates, slot, "short.name"),
-	formula.arg = "formula",
-	...) {
-	zarg <- .makeUnmarkedFitFunnyFormulas(termNames, opt, fNames)
-	if(missing(formula.arg)) { # fallback
-		nm <- names(opt$gmCall)[-1L]
-		formula.arg <- nm[grep(".*formula$", nm[1L:7L])]
-		#print(formula.arg)
-	}
-	if(length(formula.arg) == 1L && formula.arg == "formula") {
-		i <- sapply(zarg, is.null)
-		zarg[i] <- rep(list(~ 1), sum(i))
-		ret <- list(formula = call("~", zarg[[2L]], zarg[[1L]][[2L]]))
-		#attr(ret, "formulaList") <- zarg
-		ret
-	} else {
-		names(zarg) <- formula.arg
-		zarg
-	}
-}
-
-`makeArgs.unmarkedFitDS` <-
-function(obj, termNames, opt, ...)  {
-	termNames <- sub("^p\\(sigma(.+)\\)", "p(\\1)", termNames, perl = TRUE)
-	termNames[termNames == "p((Intercept))"] <- "p(1)"
-	makeArgs.unmarkedFit(obj, termNames, opt, c("lam", "p"),
-		"formula")
-}
-
 `makeArgs.coxph` <- 
 function(obj, termNames, opt, ...) {
 	ret <- makeArgs.default(obj, termNames, opt)
@@ -146,6 +92,7 @@ function(obj, termNames, opt, ...) {
 	i <- termNames %in% opt$interceptLabel
 	termNames[i] <- gsub("(Intercept)", "1", termNames[i], fixed = TRUE)
 	j <- grepl("^\\(phi\\)_", termNames)
+	# TODO: zero-length terms in reformulate
 	zarg <- list(	
 		beta = formula(terms.formula(reformulate(termNames[!j]), simplify = TRUE))
 		)
@@ -175,6 +122,7 @@ function(obj, termNames, opt, ...) {
 
 	fnames <- c("count", "zero")
 	
+	# TODO: zero-length terms in reformulate
 	zarg <- split(substring(termNames, pos + 1L, 256L),
 		substring(termNames, 1L, pos - 1L))
 	for(j in fnames) zarg[[j]] <-
@@ -225,6 +173,7 @@ function(obj, termNames, opt, ...) {
 
 `makeArgs.mark` <- 
 function(obj, termNames, opt, ...) {
+	
 	interceptLabel <- "(Intercept)"
 	termNames <- sub(interceptLabel, "1", termNames, fixed = TRUE)
 	rxres <- regexpr("^([a-zA-Z]+)\\((.*)\\)$", termNames, perl = TRUE)
@@ -232,21 +181,21 @@ function(obj, termNames, opt, ...) {
 	cl <- attr(rxres, "capture.length")
 	parname <- substring(termNames, cs[, 1L], cs[, 1L] + cl[,1L] - 1L)
 	parval <- substring(termNames, cs[, 2L], cs[, 2L] + cl[,2L] - 1L)
-	
-	#formulaList <- lapply(split(parval, parname), function(x) {
-	#	int <- x == "1"
-	#	x <- x[!int]
-	#	res <- if(!length(x))
-	#			if(int) ~ 1 else ~ 0 else 
-	#		reformulate(x, intercept = any(int))
-	#	environment(res) <- opt$gmFormulaEnv
-	#	res
-	#})
+
+	formulaList <- lapply(split(parval, parname), function(x) {
+		int <- x == "1"
+		x <- x[!int]
+		res <- if(!length(x))
+				if(int) ~ 1 else ~ 0 else 
+			reformulate(x, intercept = any(int))
+		environment(res) <- opt$gmFormulaEnv
+		res
+	})
 	
 	mpar <- if(is.null(obj$model.parameters))
 		eval(opt$gmCall$model$parameters) else
 		obj$model.parameters
-	#for(i in names(mpar)) mpar[[i]]$formula <- formulaList[[i]]
+	for(i in names(mpar)) mpar[[i]]$formula <- formulaList[[i]]
 	#ret <- list(model.parameters = mpar)
 	
 	if(opt$gmCall[[1L]] == "run.mark.model") {
@@ -258,6 +207,7 @@ function(obj, termNames, opt, ...) {
 	}
 	
 	#attr(ret, "formulaList") <- formulaList
+
 	ret
 }
 
