@@ -183,32 +183,57 @@ function(x, split = ":",
 
 getResponseFormula <-
 function(f) {
-	f <- formula(f)
+	f <- if(!is.null(tf <- attr(f, "terms"))) {
+		formula(tf)
+	} else formula(f)
 	if((length(f) == 2L) || (is.call(f[[2L]]) && f[[2L]][[1L]] == "~"))
 		0 else f[[2L]]
 }
 
 get.response <-
-function(x, ...)
+function(x, data = NULL, ...)
 UseMethod("get.response")
 
-get.response.default <-
-function(x, ...) {
-	model.frame(x)[, asChar(getResponseFormula(x), control = NULL)]
+get.response.formula <-
+function(x, data = NULL, ...) {
+	x <- terms(x)
+	if(!inherits(attr(data, "terms"), "terms")) 
+		data <- model.frame(x, data = data, ...)
+	data[, asChar(attr(x, "variables")[[attr(x, "response") + 1L]])]
 }
 
 get.response.lm <-
-function(x, ...)
-if((family(x)$family != "binomial") && !is.null(x$y)) x$y else NextMethod()
+function(x, data = NULL, ...) {
+	if(missing(data) && (family(x)$family != "binomial") && !is.null(x$y))
+		x$y else
+		#get.response.default(x, data = data, ...)
+		NextMethod()
+}
 # NOTE: for 'binomial' 'y' is a vector not nmatrix2
 
 get.response.averaging <-
-function(x, ...) {
+function(x, data = NULL, ...) {
 	if(is.null(attr(x, "modelList")))
 		stop("'x' has no model list")
-	get.response(attr(x, "modelList")[[1L]])
+	get.response(attr(x, "modelList")[[1L]], data = data, ...)
 }
 
+get.response.default <-
+function(x, data = NULL, ...) {
+	if(is.null(data)) {
+		# model frame:
+		if(is.data.frame(x) && !is.null(tf <- attr(x, "terms"))) {
+			tf <- terms(x)
+			return(x[, asChar(attr(tf, "variables")[[attr(tf, "response") + 1L]])])
+		} else data <- model.frame(x)
+	}
+	#model.frame(x)[, asChar(getResponseFormula(x))]
+	if(is.null(data)) data <- model.frame(x)
+	get.response(terms(x), data = data, ...)
+}
+
+
+
 
 #Tries to find out whether the models are fitted to the same data
 .checkModels <-
@@ -237,7 +262,7 @@ function(models, error = TRUE) {
 	nresid <- vapply(models, function(x) nobs(x), 1) # , nall=TRUE
 
 	if(!all(sapply(datas[-1L], identical, datas[[1L]])) ||
-		!all(nresid[-1L] == nresid[[1L]])) {
+		!all(nresid == nresid[[1L]])) { # better than 'nresid[-1L] == nresid[[1L]]'
 		# XXX: na.action checking here
 		err("models are not all fitted to the same data")
 		res <- FALSE
@@ -292,7 +317,7 @@ function(x, minlength = 4, minwordlen = 1,
 			gsub("([\\(,]) *\\w+ *= *", "\\1", x, perl = TRUE), perl = TRUE)
 		else dx <- x
 
-	#DebugPrint(x)
+	#.DebugPrint(x)
 	s <- strsplit(dx, "(?=[\\W_])", perl = TRUE)
 	# remove I(...):
 	s <- lapply(s, function(z) {
@@ -449,7 +474,7 @@ function(x, fam = x$family, link = x$link) {
 
 `commonCallStr` <-
 function(models, calls = lapply(models, get_call)) {
-
+	
 	x <- lapply(calls, as.list)
 	alln <- unique(unlist(lapply(x, names)))
 	uniq <- vector("list", length(alln))
@@ -466,7 +491,10 @@ function(models, calls = lapply(models, get_call)) {
 	j <- nu > 1 & !j
 	rval[j] <- paste("<", nu[j], " unique values>", sep = "")
 	if(nu[1L] > 1) rval[[1L]] <- paste(sapply(uniq[[1L]], asChar), collapse = "|")
-	rval <- paste(rval[[1L]], "(", paste(names(rval[-1L]), "=", rval[-1L], collapse = ", "), ")", sep = "")
+		
+	rval <- paste(deparse(rval[[1L]], control = NULL),
+		"(", paste(names(rval[-1L]), "=", rval[-1L], collapse = ", "), ")", sep = "")
+	
 	rval <- sub("`__(\\d+)-rhsform__`", "<\\1 unique rhs>", rval, perl = TRUE)
 	rval
 
